@@ -41,3 +41,12 @@ from _muGrid import (get_domain_ccoord, get_domain_index, Pixel, StorageOrder,
                      SubPt, DynCcoord, DynRcoord, IterUnit, Verbosity,
                      GlobalFieldCollection, LocalFieldCollection, Unit)
 
+# FileIONetCDF is only compiled into the library if NetCDF libraries exist
+try:
+    from _muGrid import FileIONetCDF
+except ImportError:
+    pass
+
+from .Parallel import Communicator
+
+has_mpi = _muGrid.Communicator.has_mpi
