@@ -53,8 +53,7 @@ namespace muGrid {
         nb_cols{this->field.get_default_nb_cols(iter_type)} {
     if (field.get_storage_order() != StorageOrder::ColMajor) {
       std::stringstream s;
-      s << "FieldMap requires column-major storage order, but storage order of "
-        << "field '" << field.get_name() << "' is "
+      s << "FieldMap requires column-major storage order, but storage order is "
         << field.get_storage_order();
       throw RuntimeError(s.str());
     }
@@ -77,8 +76,7 @@ namespace muGrid {
         nb_rows{nb_rows_}, nb_cols{this->stride / nb_rows_} {
     if (field.get_storage_order() != StorageOrder::ColMajor) {
       std::stringstream s;
-      s << "FieldMap requires column-major storage order, but storage order of "
-        << "field '" << field.get_name() << "' is "
+      s << "FieldMap requires column-major storage order, but storage order is "
         << field.get_storage_order();
       throw RuntimeError(s.str());
     }
@@ -108,8 +106,7 @@ namespace muGrid {
         data_ptr{other.data_ptr}, is_initialised{other.is_initialised} {
     if (field.get_storage_order() != StorageOrder::ColMajor) {
       std::stringstream s;
-      s << "FieldMap requires column-major storage order, but storage order of "
-        << "field '" << field.get_name() << "' is "
+      s << "FieldMap requires column-major storage order, but storage order is "
         << field.get_storage_order();
       throw RuntimeError(s.str());
     }
@@ -224,12 +221,6 @@ namespace muGrid {
     return mean;
   }
 
-  /* ---------------------------------------------------------------------- */
-  template <typename T, Mapping Mutability>
-  auto FieldMap<T, Mutability>::get_field() const -> const Field_t & {
-    return this->field;
-  }
-
   /* ---------------------------------------------------------------------- */
   template class FieldMap<Real, Mapping::Const>;
   template class FieldMap<Real, Mapping::Mut>;
